@@ -56,9 +56,7 @@ particular which module inherits off which.
 
 =head1 METHODS
 
-=over 4
-
-=item register_class <component> <component_class>
+=head2 register_class <component> <component_class>
 
 Registers the class in the schema's class_registrations. This is a hash
 containing database classes, keyed by their monikers. It's used by
@@ -73,7 +71,7 @@ sub register_class {
   $class->class_registrations(\%reg);
 }
 
-=item registered_classes
+=head2 registered_classes
 
 Simple read-only accessor for the schema's registered classes. See 
 register_class above if you want to modify it.
@@ -85,32 +83,63 @@ sub registered_classes {
   return values %{shift->class_registrations};
 }
 
-=item  load_classes [<classes>}
+=head2  load_classes [<classes>, (<class>, <class>), {<namespace> => [<classes>]}]
 
 Uses L<Module::Find> to find all classes under the database class' namespace,
 or uses the classes you select.  Then it loads the component (using L<use>), 
 and registers them (using B<register_class>);
 
+It is possible to comment out classes with a leading '#', but note that perl
+will think it's a mistake (trying to use a comment in a qw list) so you'll
+need to add "no warnings 'qw';" before your load_classes call.
+
 =cut
 
 sub load_classes {
-  my $class = shift;
-  my @comp = grep { $_ !~ /^#/ } @_;
-  unless (@comp) {
+  my ($class, @params) = @_;
+  
+  my %comps_for;
+  
+  if (@params) {
+    foreach my $param (@params) {
+      if (ref $param eq 'ARRAY') {
+        # filter out commented entries
+        my @modules = grep { $_ !~ /^#/ } @$param;
+        
+        push (@{$comps_for{$class}}, @modules);
+      }
+      elsif (ref $param eq 'HASH') {
+        # more than one namespace possible
+        for my $comp ( keys %$param ) {
+          # filter out commented entries
+          my @modules = grep { $_ !~ /^#/ } @{$param->{$comp}};
+
+          push (@{$comps_for{$comp}}, @modules);
+        }
+      }
+      else {
+        # filter out commented entries
+        push (@{$comps_for{$class}}, $param) if $param !~ /^#/;
+      }
+    }
+  } else {
     eval "require Module::Find;";
     $class->throw("No arguments to load_classes and couldn't load".
       " Module::Find ($@)") if $@;
-    @comp = map { substr $_, length "${class}::"  }
-              Module::Find::findallmod($class);
+    my @comp = map { substr $_, length "${class}::"  } Module::Find::findallmod($class);
+    $comps_for{$class} = \@comp;
   }
-  foreach my $comp (@comp) {
-    my $comp_class = "${class}::${comp}";
-    eval "use $comp_class"; # If it fails, assume the user fixed it
-    $class->register_class($comp => $comp_class);
+
+  foreach my $prefix (keys %comps_for) {
+    foreach my $comp (@{$comps_for{$prefix}||[]}) {
+      my $comp_class = "${prefix}::${comp}";
+      eval "use $comp_class"; # If it fails, assume the user fixed it
+      $class->register_class($comp => $comp_class);
+    }
   }
 }
 
-=item compose_connection <target> <@db_info>
+=head2 compose_connection <target> <@db_info>
 
 This is the most important method in this class. it takes a target namespace,
 as well as dbh connection info, and creates a L<DBIx::Class::DB> class as
@@ -153,7 +182,7 @@ sub compose_connection {
   $conn_class->class_resolver($target);
 }
 
-=item setup_connection_class <$target> <@info>
+=head2 setup_connection_class <$target> <@info>
 
 Sets up a database connection class to inject between the schema
 and the subclasses the schema creates.
@@ -169,8 +198,6 @@ sub setup_connection_class {
 
 1;
 
-=back
-
 =head1 AUTHORS
 
 Matt S. Trout <mst@shadowcatsystems.co.uk>
